Package: timeperiodsR
Type: Package
Title: Simple Definition Of Time Intervals
Version: 0.7.7
License: GPL-2
Authors@R: 
    c(person(given  = "Alexey",
             family = "Seleznev",
             role   = c("aut", "cre"),
             email  = "selesnow@gmail.com"))
Author: Alexey Seleznev [aut, cre]
Maintainer: Alexey Seleznev <selesnow@gmail.com>
Description: Simple definition of time intervals for the current, previous, and next week, month, quarter and year.
BugReports: https://github.com/selesnow/timeperiodsR/issues
URL: https://selesnow.github.io/timeperiodsR/,
        https://t.me/R4marketing,
        https://www.youtube.com/playlist?list=PLD2LDq8edf4qed2KVKfXmKdh0OQcdj9gw
Imports: lubridate
VignetteBuilder: knitr
Suggests: knitr, rmarkdown, httr
Encoding: UTF-8
Language: en, ru
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-05-12 10:29:40 UTC; User
Repository: CRAN
Date/Publication: 2026-05-12 10:40:01 UTC
Built: R 4.6.0; ; 2026-05-12 14:58:56 UTC; unix
