export(last_n_days)
export(last_n_weeks)
export(last_n_months)
export(last_n_quarters)
export(last_n_years)
export(previous_week)
export(previous_month)
export(previous_quarter)
export(previous_year)
export(this_week)
export(this_month)
export(this_quarter)
export(this_year)
export(next_week)
export(next_month)
export(next_quarter)
export(next_year)
export(next_n_days)
export(next_n_weeks)
export(next_n_months)
export(next_n_quarters)
export(next_n_years)
export(custom_period)
export(as_timeperiod)
export(weekends)
export(workdays)
export(first_workday)
export(last_workday)
export(first_weekend)
export(last_weekend)
export(weekends_length)
export(workdays_length)
export(last_weekend)
export(check_dayoffs)
export("%.in%")
export("%left_out%")
export("%left_in%")
export("%right_out%")
export("%right_in%")
importFrom(lubridate, ceiling_date, floor_date, days, weeks, years, dmonths)
importFrom(stats, start, end)
importFrom(utils, install.packages, installed.packages)
S3method("as_timeperiod",Date)
S3method("as_timeperiod",default)
S3method("print",tpr)
S3method("seq",tpr)
S3method("length",tpr)
S3method("start",tpr)
S3method("end",tpr)
S3method("workdays", default)
S3method("workdays", tpr)
S3method("weekends", default)
S3method("weekends", tpr)
S3method("first_workday", default)
S3method("first_workday", tpr)
S3method("last_workday", default)
S3method("last_workday", tpr)
S3method("first_weekend", default)
S3method("first_weekend", tpr)
S3method("last_weekend", default)
S3method("last_weekend", tpr)
S3method("weekends_length", default)
S3method("weekends_length", tpr)
S3method("workdays_length", default)
S3method("workdays_length", tpr)
S3method("[[<-", tpr)
S3method("[<-", tpr)
